/*
 *=============================================================================
* EMBL - European Bioinformatics institute
* MSD Group
* VAMSAS Project
* 
*  Copyright (c) 2005 The European Bioinformatics Institute. All rights reserved.
*  
*   Redistribution and use in source and binary forms, with or without
*   modification.
*
*The European Bioinformatics Institute may publish revised and/or new 
*versions of this license with new releases of VAMSAS software. 
*==============================================================================
 *
 * 
 * Created on Feb 22, 2006
 *
 * @author <a href="mailto:pierre@ebi.ac.uk">Pierre MARGUERITE</a>
 * @version  2  
 * @since 22 Feb. 2006
 */
package uk.ac.ebi.msd.vamsas.vamav;

import java.io.File;

import org.vamsas.client.ClientHandle;
import org.vamsas.client.Events;
import org.vamsas.client.IClientDocument;
import org.vamsas.client.InvalidSessionUrnException;
import org.vamsas.client.UserHandle;
import org.vamsas.client.simpleclient.SimpleClient;
import org.vamsas.client.simpleclient.VamsasSession;

import uk.ac.ebi.msd.vamsas.vamav.communication.astexviewer.AVClientIntf;
import uk.ac.ebi.msd.vamsas.vamav.session.VAMAVSession;
import uk.ac.ebi.msd.vamsas.vamav.util.logger.VAMAVLogger;
import uk.ac.ebi.msd.vamsas.vamav.util.logger.VAMAVLoggerImpl;


/**
 * This class represents a VAMSAS client in the VAMSAS workflow (VAMSAS Client API),
 *  
 * @author <a href="mailto:pierre@ebi.ac.uk">Pierre MARGUERITE</a>
 * @since 22 Feb. 2006
 * @version 2 
 * 
 */
public class VAMAVClient extends SimpleClient {


	private String lastStatus = Events.DOCUMENT_CREATE; 
	private final VAMAVLogger logger = new VAMAVLoggerImpl(this.getClass());
	private VAMAVSession vamavSession = null;
	private AVClientIntf avclient = null;
	private VamsasSession sess = null;
	private IClientDocument document = null;
	
	
	/**
	 * Should not be used
	 * @param applicationHandle application handle for the current application
	 * @throws InvalidSessionUrnException if a error occurs during the creation of the client and the session.
	 */
	@Deprecated
	public VAMAVClient (ClientHandle applicationHandle)throws InvalidSessionUrnException
	{
		super(null, applicationHandle, null);
		this.client = applicationHandle;
		
	}
	/**
	 * Inits a client with a given user and a given Client handle in a given session
	 * @param user  information, of the user opening the session
	 * @param client the clientHandle
	 * @param sess Session in which is opened the client.
	 * @throws InvalidSessionUrnException if a error occurs during the creation of the client and the session.
	 
	 */
	public VAMAVClient (
		UserHandle user,
		ClientHandle client,
		VamsasSession _sess) throws InvalidSessionUrnException{
		super(user, client, _sess);
		this.sess = _sess;
	}

	/**
	 * Inits a client with a given user and a given Client handle in a given session
	 * and an archive file from a previous session/treatment
	 * @param user  information, of the user opening the session
	 * @param client the clientHandle
	 * @param _sess Session in which is opened the client.
	 * @param importingArchive
	 * 
	 * @throws Exception raises if an error occurs during the creation of the client (archive reading, incorrect session, ...)
	 */
	public VAMAVClient(
		UserHandle user,
		ClientHandle client,
		VamsasSession _sess,
		File importingArchive)
		throws Exception {
		super(user, client, _sess, importingArchive);
		this.sess = _sess;
	}

	/**
		  * @see org.vamsas.client.IClient#getAbout()
		  */
		 public String getAbout() {
		   return new String("VAMAV Client version $version$ build $build$");
		 }
	
	/**
		   * a clone the current VAMSASClient object
		   * @return a clone object of the current object
		   */
		  public Object clone()
			  {
				  VAMAVClient client = null;
				  try
					  {
						  client = new VAMAVClient(this.user, this.client, this.sess);//this.SessionUrn);
				  //client.setVAMAVDocument(this.getClientDocument());
					  }
				  catch (InvalidSessionUrnException isuE)
					  {
						  this.logger.appliError("Unable to clone client.");
						  this.logger.sessionError("Unable to clone client.");
						  client = null;
					  }
				  return client;
			  }

		/**
		 * Retrieves the  vAMAVSession attribut
		 *
		 * @return Returns the vAMAVSession.
		 */
		public VAMAVSession getVAMAVSession()
			{
				return this.vamavSession;
			}

		/**
		 *Sets session attribut
		 *
		 * @param session The vAMAVSession to set.
		 */
		public void setVAMAVSession(VAMAVSession session)
			{
				this.vamavSession = session;
				this.logger.setSession(session);
			}

		/**
		 * Retrieves the  avclient attribut
		 *
		 * @return Returns the avclient.
		 */
		public AVClientIntf getAvclient()
			{
				return this.avclient;
			}

		/**
		 *Sets avclient attribut
		 *
		 * @param avclient The avclient to set.
		 */
		public void setAvclient(AVClientIntf avclient)
			{
				this.avclient = avclient;
			}
/**
 * Set current document associated to the current client
 * @param document the document object to associate to the client
 */
	public void setVAMAVDocument(IClientDocument document)
			 {
				 if (document != null)
					 {
						 this.document = document;
					 }
			 }
			 
			 public void setUser(UserHandle _user)
			 {
			 	if (_user !=null)
			 	{
			 		this.user = _user;
			 	}
			 }
}
